@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2019 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -126,8 +126,8 @@ static gint			x_scroll,
 static MeminfoMeter	*mon_in_motion;
 
 
-static void	(*read_mem_data)();
-static void	(*read_swap_data)();
+static GkrellmMemReadMemFunc read_mem_data;
+static GkrellmMemReadSwapFunc read_swap_data;
 
 
 static gint
@@ -142,7 +142,8 @@ setup_meminfo_interface(void)
 	}
 
 void
-gkrellm_mem_client_divert(void (*read_mem_func)(), void (*read_swap_func)())
+gkrellm_mem_client_divert(GkrellmMemReadMemFunc read_mem_func,
+				GkrellmMemReadSwapFunc read_swap_func)
 	{
 	read_mem_data = read_mem_func;
 	read_swap_data = read_swap_func;
@@ -544,7 +545,7 @@ meminfo_expose_event(GtkWidget *widget, GdkEventExpose *ev)
 	else if (swap_chart.chart && widget == swap_chart.chart->drawing_area)
 		pixmap = swap_chart.chart->pixmap;
 	if (pixmap)
-		gdk_draw_drawable(widget->window, gkrellm_draw_GC(1), pixmap,
+		gdk_draw_drawable(gtk_widget_get_window(widget), gkrellm_draw_GC(1), pixmap,
 				ev->area.x, ev->area.y, ev->area.x, ev->area.y,
 				ev->area.width, ev->area.height);
 	return FALSE;
@@ -662,8 +663,9 @@ cb_panel_motion(GtkWidget *widget, GdkEventButton *ev)
 	}
 
 static void
-setup_scaling(GkrellmChartconfig *cf, MeminfoChart *mc)
+setup_scaling(GkrellmChartconfig *cf, gpointer data)
 	{
+	MeminfoChart* mc = (MeminfoChart*)data;
 	GkrellmChart	*cp	  = mc->chart;
 	gint	res   = DEFAULT_GRID_RES,
 			grids = FULL_SCALE_GRIDS;
@@ -723,9 +725,9 @@ create_chart(MeminfoChart *mc, gint first_create)
 
 	if (first_create)
 		{
-		g_signal_connect(G_OBJECT(cp->drawing_area), "expose_event",
+		g_signal_connect(G_OBJECT(cp->drawing_area), "expose-event",
 					G_CALLBACK(meminfo_expose_event), NULL);
-		g_signal_connect(G_OBJECT(cp->drawing_area), "button_press_event",
+		g_signal_connect(G_OBJECT(cp->drawing_area), "button-press-event",
 					G_CALLBACK(cb_extra), mc);
 		gtk_widget_show(mc->vbox);
 		}
@@ -738,17 +740,17 @@ create_chart(MeminfoChart *mc, gint first_create)
 static void
 connect_panel_signals(GkrellmPanel *p, MeminfoMeter *mm)
 		{
-		g_signal_connect(G_OBJECT (p->drawing_area), "expose_event",
+		g_signal_connect(G_OBJECT (p->drawing_area), "expose-event",
 					G_CALLBACK(meminfo_expose_event), NULL);
-		g_signal_connect(G_OBJECT(p->drawing_area), "button_press_event",
+		g_signal_connect(G_OBJECT(p->drawing_area), "button-press-event",
 					G_CALLBACK(cb_panel_press), mm);
-		g_signal_connect(G_OBJECT(p->drawing_area), "button_release_event",
+		g_signal_connect(G_OBJECT(p->drawing_area), "button-release-event",
 					G_CALLBACK(cb_panel_release), NULL);
-		g_signal_connect(G_OBJECT(p->drawing_area), "motion_notify_event",
+		g_signal_connect(G_OBJECT(p->drawing_area), "motion-notify-event",
 					G_CALLBACK(cb_panel_motion), NULL);
-		g_signal_connect(G_OBJECT(p->drawing_area), "enter_notify_event",
+		g_signal_connect(G_OBJECT(p->drawing_area), "enter-notify-event",
 					G_CALLBACK(cb_panel_enter), mm);
-		g_signal_connect(G_OBJECT(p->drawing_area), "leave_notify_event",
+		g_signal_connect(G_OBJECT(p->drawing_area), "leave-notify-event",
 					G_CALLBACK(cb_panel_leave), mm);
 		}
 
@@ -1130,7 +1132,7 @@ cb_mem_enable(GtkWidget *button, gpointer data)
     {
 	gboolean enabled;
 
-	enabled = GTK_TOGGLE_BUTTON(button)->active;
+	enabled = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
 	gkrellm_panel_enable_visibility(mem.panel, enabled, &mem.enabled);
 	spacer_visibility();
 	gtk_widget_set_sensitive(mem_alert_button, enabled);
@@ -1141,7 +1143,7 @@ cb_swap_enable(GtkWidget *button, gpointer data)
     {
 	gboolean enabled;
 
-	enabled = GTK_TOGGLE_BUTTON(button)->active;
+	enabled = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
 	gkrellm_panel_enable_visibility(swap.panel, enabled, &swap.enabled);
 	spacer_visibility();
 	gtk_widget_set_sensitive(swap_alert_button, enabled);
@@ -1152,7 +1154,7 @@ cb_swap_chart_enable(GtkWidget *button, gpointer data)
     {
 	gboolean enabled;
 
-	enabled = GTK_TOGGLE_BUTTON(button)->active;
+	enabled = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
 	if (enabled && !swap_chart.enabled)
 		create_chart(&swap_chart, TRUE);
 	else if (!enabled && swap_chart.enabled)
@@ -1177,7 +1179,7 @@ cb_all_krells(GtkWidget *button, gpointer data)
     {
 	gboolean enabled;
 
-	enabled = GTK_TOGGLE_BUTTON(button)->active;
+	enabled = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
 	if (enabled && !mem.all_krells)
 		{		/* krell list order needs to be: cache, buffer, used */
 		gkrellm_insert_krell(mem.panel, mem.krell_buffers, FALSE);
@@ -1348,23 +1350,23 @@ create_meminfo_tab(GtkWidget *tab_vbox)
 	vbox1 = gkrellm_gtk_category_vbox(vbox,
 				_("Format String for Chart Labels"),
 				4, 0, TRUE);
-	text_format_combo_box = gtk_combo_box_entry_new_text();
+	text_format_combo_box = gtk_combo_box_text_new_with_entry();
 	gtk_box_pack_start(GTK_BOX(vbox1), text_format_combo_box, FALSE, FALSE, 2);
 
-	gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box),
 		text_format);
-	gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box),
 		DEFAULT_TEXT_FORMAT);
-	gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box),
 		"$T\\C\\f$M");
-	gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box),
 		"\\c\\f$M\\b$T");
-	gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box),
 		"\\ww\\C\\f$M\\D2\\f\\ai\\.$i\\D1\\f\\ao\\.$o");
-	gtk_combo_box_append_text(GTK_COMBO_BOX(text_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(text_format_combo_box),
 		"\\ww\\C\\f$M\\D3\\f\\ai\\.$i\\D0\\f\\ao\\.$o");
 	gtk_combo_box_set_active(GTK_COMBO_BOX(text_format_combo_box), 0);
-	g_signal_connect(G_OBJECT(GTK_COMBO_BOX(text_format_combo_box)), "changed",
+	g_signal_connect(G_OBJECT(text_format_combo_box), "changed",
 			G_CALLBACK(cb_text_format), NULL);
 
 	vbox1 = gkrellm_gtk_category_vbox(vbox,
@@ -1372,21 +1374,21 @@ create_meminfo_tab(GtkWidget *tab_vbox)
 				4, 6, TRUE);
 	hbox = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
-	mem_format_combo_box = gtk_combo_box_entry_new_text();
+	mem_format_combo_box = gtk_combo_box_text_new_with_entry();
 	gtk_box_pack_start(GTK_BOX(hbox), mem_format_combo_box, TRUE, TRUE, 0);
-	gtk_combo_box_append_text(GTK_COMBO_BOX(mem_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(mem_format_combo_box),
 		mem.data_format);
-	gtk_combo_box_append_text(GTK_COMBO_BOX(mem_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(mem_format_combo_box),
 		DEFAULT_FORMAT);
-	gtk_combo_box_append_text(GTK_COMBO_BOX(mem_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(mem_format_combo_box),
 		_("$t - $u used"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(mem_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(mem_format_combo_box),
 		_("$t - $U"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(mem_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(mem_format_combo_box),
 		_("$t - $u used  $s sh  $b bf  $c ca"));
 	gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(mem_format_combo_box))),
 			mem.data_format);
-	g_signal_connect(G_OBJECT(GTK_COMBO_BOX(mem_format_combo_box)), "changed",
+	g_signal_connect(G_OBJECT(mem_format_combo_box), "changed",
 			G_CALLBACK(cb_mem_format), NULL);
 	label = gtk_label_new(_("Mem"));
 	gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_LEFT);
@@ -1395,19 +1397,19 @@ create_meminfo_tab(GtkWidget *tab_vbox)
 
 	hbox = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
-	swap_format_combo_box = gtk_combo_box_entry_new_text();
+	swap_format_combo_box = gtk_combo_box_text_new_with_entry();
 	gtk_box_pack_start(GTK_BOX(hbox), swap_format_combo_box, TRUE, TRUE, 0);
-	gtk_combo_box_append_text(GTK_COMBO_BOX(swap_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(swap_format_combo_box),
 		swap.data_format);
-	gtk_combo_box_append_text(GTK_COMBO_BOX(swap_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(swap_format_combo_box),
 		DEFAULT_FORMAT);
-	gtk_combo_box_append_text(GTK_COMBO_BOX(swap_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(swap_format_combo_box),
 		_("$t - $u used"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(swap_format_combo_box),
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(swap_format_combo_box),
 		_("$t - $U"));
 	gtk_entry_set_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(swap_format_combo_box))),
 			swap.data_format);
-	g_signal_connect(G_OBJECT(GTK_COMBO_BOX(swap_format_combo_box)), "changed",
+	g_signal_connect(G_OBJECT(swap_format_combo_box), "changed",
 			G_CALLBACK(cb_swap_format), NULL);
 	label = gtk_label_new(_("Swap"));
 	gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_LEFT);
@@ -1456,7 +1458,7 @@ static GkrellmMonitor	monitor_mem =
 	create_meminfo_tab, /* The config tab create function	*/
 	NULL, 				/* Instant apply */
 
-	save_meminfo_config, /* Save user conifg			*/
+	save_meminfo_config, /* Save user config			*/
 	load_meminfo_config, /* Load user config			*/
 	MEM_CONFIG_KEYWORD, /* config keyword			*/
 
@@ -1495,7 +1497,7 @@ static GkrellmMonitor	monitor_swap =
 	NULL,			/* The update function		*/
 	NULL,			/* The config tab create function	*/
 	NULL,			/* Apply the config function		*/
-	NULL,			/* Save user conifg			*/
+	NULL,			/* Save user config			*/
 	NULL,			/* Load user config			*/
 	NULL,			/* config keyword			*/
 	NULL,			/* Undef 2	*/
